//------------------------------------------------------------------------------------------------
// SSD1311_Full.ino
// Copyright (c) 2014, 2015, 2016, 2017, 2018 by Haute Solutions / Ed Van Every (www.haute-solutions.com)
//
// Program for writing to OLED Displays based on the SSD1311 controller.
//
// - Supports I2C Interface Mode Only
// - Autodetects/configures for both Arduino and Mega I2C Pinouts
// - Supports flexible address, row and column geometry via class construction intitialization
// - Requires the OLED_SSD1311 OLED Class Library (by Haute Solutions)
//
// LICENSE:  This is free software: you can redistribute it and/or modify
//           it under the terms of the GNU General Public License as published by
//           the Free Software Foundation, either version 3 of the License, or
//           (at your option) any later version.
//
//           This program is distributed in the hope that it will be useful,
//           but WITHOUT ANY WARRANTY; without even the implied warranty of
//           MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//           GNU General Public License for more details.
//           <http://www.gnu.org/licenses/>.
//
//------------------------------------------------------------------------------------------------

#include <Arduino.h>
#include <Wire.h>

#include "OLED_SSD1311.h"
OLED oled(0x3C);                                        // I2C Address

void setup() {
  oled.Init();                                          // Init the Display
  oled.Clear();                                         // Clear the display
}

void loop() {
int i;
char spinner[]={0xFE,0x2F,0x2D,0xFB};

  // Display some Strings (using "Display" function: {Line1Text, Line2Text, Center (Default=0)} )
  oled.Display("Haute Solutions", "OLED Display", 1);
  delay(2000);

  // Replace the first line and clear the second line (using "Display" function: {Line1Text, Line2Text, Center (Default=0)} )
  oled.Display("1st Line", "",1);
  delay(2000);

  // Replace the second line and leave first line intact (using "Display" function: {Line1Text, Line2Text, Center (Default=0)} )
  oled.Display(NULL, "2nd Line",1);
  delay(2000);

  // Just write single lines (Using "DisplayLine" function: {LineNo, Text, Center (Default=0)} )
  oled.DisplayLine(1, "Center Off");
  oled.DisplayLine(2, "Center On",1);
  delay(2000);

  // Display some Characters (using "DisplayChar" function: {Row, Col, Char} )
  for(i=0; i<oled._Cols; i++) {
    oled.DisplayChar(1,i+1,'a'+i);        // Writing Line 1
    oled.DisplayChar(2,i+1,'A'+i);        // Writing Line 2
  }
  delay(2000);

  // Quick Character Updates
  oled.Display("Spinning:","");           // Set the static text with "Display" function
  for(i=0; i<100; i++) {
    oled.DisplayChar(1,11,spinner[i%4]);  // Update just one char with "DisplayChar" function
    delay(100);
  }

  // End of Loop
  oled.Display("Thats All Folks!", "(Starting Over)");
  delay(2000);

}




