//------------------------------------------------------------------------------------------------
// OLED_SSD1311 OLED Library
// Copyright (c) 2014, 2015, 2016, 2017, 2018 by Haute Solutions / Ed Van Every (www.haute-solutions.com)
//
// FUNCTION: This Library is intended to control Character OLEDs based on the SSD1311 controller
//
// - Supports I2C Interface Mode Only
// - Autodetects/configures for both Arduino and Mega I2C Pinouts
//
// LICENSE:  This library is free software: you can redistribute it and/or modify
//           it under the terms of the GNU General Public License as published by
//           the Free Software Foundation, either version 3 of the License, or
//           (at your option) any later version.
//
//           This program is distributed in the hope that it will be useful,
//           but WITHOUT ANY WARRANTY; without even the implied warranty of
//           MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//           GNU General Public License for more details.
//           <http://www.gnu.org/licenses/>.
//
//------------------------------------------------------------------------------------------------

#define OLED_SSD1311_LIBVER "1.1"

#ifndef OLED_SSD1311_h
#define OLED_SSD1311_h

// We'll try and determine I2C ports automatically...
#if defined(__AVR_ATmega328P__) || defined(__AVR_ATmega168__)
#define OLED_I2C_ARDUINO
#endif 
#if defined(__AVR_ATmega1280__) || defined(__AVR_ATmega2560__)
#define OLED_I2C_MEGA
#endif
#if defined(ESP32)
#define OLED_I2C_ESP32
#endif 
 
// Otherwise uncomment ONE of the following...
//#define OLED_I2C_ARDUINO
//#define OLED_I2C_MEGA
//#define OLED_I2C_ESP32

#ifdef OLED_I2C_ARDUINO
	#define ASDA  A4
	#define ASCL  A5
#endif

#ifdef OLED_I2C_MEGA
	#define ASDA  20
	#define ASCL  21
#endif

#ifdef OLED_I2C_ESP32
	#define ASDA	21
	#define ASCL	22
#endif

#define OLED_ROWS 2
#define OLED_COLS 16

#include <Arduino.h>
#include <Wire.h>

// ------------------------------------------------------

class OLED
{
	public:
		// High Level Functions
		OLED(char address=0x3C);
		void RollDisplay(char *Line2, int Center=0);
		void Display(char *Line1, char *Line2, int Center=0);
		void DisplayLine(int Line, char *Text, int Center=0);
		void DisplayChar(int Row, int Col, char C);
		void Clear();
		void Init();
		void On();
		void Off();
		// Low Level Functions
		void Command(unsigned char c);
		void Data(unsigned char d);
		void SendPacket(unsigned char x);
		// Data
		char _Address;
		int  _L1_Offset;
		int  _L2_Offset;
		unsigned char _Packet[20]={0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};
	private:
		char _Line1[OLED_COLS+1];
		char _Line2[OLED_COLS+1];		
};

#endif
